Module remove

Module remove 

ScalarUDFImpl definitions for array_remove, array_remove_n, array_remove_all functions.

Structs

ArrayRemove
ArrayRemoveAll
ArrayRemoveN

Functions

array_remove
removes the first element from the array equal to the given value. NULL elements already in the array are preserved when removing a non-NULL value. If element evaluates to NULL, the result is NULL rather than removing NULL entries.
array_remove_all
removes all elements from the array equal to the given value. NULL elements already in the array are preserved when removing a non-NULL value. If element evaluates to NULL, the result is NULL rather than removing NULL entries.
array_remove_all_udf
ScalarFunction that returns a ScalarUDF for ArrayRemoveAll
array_remove_n
removes the first max elements from the array equal to the given value. NULL elements already in the array are preserved when removing a non-NULL value. If element evaluates to NULL, the result is NULL rather than removing NULL entries.
array_remove_n_udf
ScalarFunction that returns a ScalarUDF for ArrayRemoveN
array_remove_udf
ScalarFunction that returns a ScalarUDF for ArrayRemove