pub fn array_remove_all(array: Expr, element: Expr) -> ExprExpand description
removes all elements from the array equal to the given value. NULL elements already in the array are preserved when removing a non-NULL value. If element evaluates to NULL, the result is NULL rather than removing NULL entries.