ScalarUDFImpl definitions for array_remove, array_remove_n, array_remove_all functions.
Structs
Functions
- array_
remove - removes the first element from the array equal to the given value. NULL elements already in the array are preserved when removing a non-NULL value. If
elementevaluates to NULL, the result is NULL rather than removing NULL entries. - array_
remove_ all - removes all elements from the array equal to the given value. NULL elements already in the array are preserved when removing a non-NULL value. If
elementevaluates to NULL, the result is NULL rather than removing NULL entries. - array_
remove_ all_ udf - ScalarFunction that returns a
ScalarUDFfor ArrayRemoveAll - array_
remove_ n - removes the first
maxelements from the array equal to the given value. NULL elements already in the array are preserved when removing a non-NULL value. Ifelementevaluates to NULL, the result is NULL rather than removing NULL entries. - array_
remove_ n_ udf - ScalarFunction that returns a
ScalarUDFfor ArrayRemoveN - array_
remove_ udf - ScalarFunction that returns a
ScalarUDFfor ArrayRemove